# Konza Prairie
# GRSPnests.R

rm(list=ls())	
library(RMark)
library(Hmisc)

# input file
# Names of dates and fate have to be exactly right for RMark
GRSPnests = read.csv(file.choose())
head(GRSPnests,20) #look at first 20 rows of data

(min = min(GRSPnests$FirstFound))  # needs to be 1 for dataset
(occ = max(GRSPnests$LastChecked))

# tally nests
ftable(GRSPnests$NestID, GRSPnests$Fate)
prop.table(ftable(GRSPnests$NestID, GRSPnests$Fate),1)
ftable(GRSPnests$Year, GRSPnests$Fate)
prop.table(ftable(GRSPnests$Year, GRSPnests$Fate),1)
ftable(GRSPnests$NestID, GRSPnests$Year, GRSPnests$Fate)

# Treat dummy variables as factors
GRSPnests$Year=factor(GRSPnests$Year)
GRSPnests$Parasitized=factor(GRSPnests$Parasitized)
GRSPnests$GrazingTrt=factor(GRSPnests$GrazingTrt)
GRSPnests$BurnedThisYear=factor(GRSPnests$BurnedThisYear)
GRSPnests$Watershed=factor(GRSPnests$Watershed)

#taking a look at the data
GRSPnests$BurnedThisYear
levels(GRSPnests$GrazingTrt)
GRSPnests$GrazingTrt

########################################################
# NEST SURVIVAL 



# Write a function for evaluating a set of competing models
run.GRSPnests=function()
{
  
  # A model of constant daily survival rate (DSR)
  Dot=mark(GRSPnests,nocc=occ,model="Nest",model.parameters=list(S=list(formula=~1)))
  
  #DSR varies by nestdate
  NestDate=mark(GRSPnests,nocc=occ,model="Nest",
                model.parameters=list(S=list(formula=~Time)))
  
   # DSR follows a quadratic trend 
  Dateq=mark(GRSPnests,nocc=occ,model="Nest",model.parameters=list(S=list(formula=~Time+I(Time^2))))
  
  # DSR varies by year
  Year=mark(GRSPnests,nocc=occ,model="Nest",
            model.parameters=list(S=list(formula=~Year)), groups="Year")
  
  # DSR varies by Parasitized
  Parasitized=mark(GRSPnests,nocc=occ,model="Nest",
                   model.parameters=list(S=list(formula=~Parasitized)), groups="Parasitized")
  
      # DSR varies by GrazingTrt
  GrazingTrt=mark(GRSPnests,nocc=occ,model="Nest",
                  model.parameters=list(S=list(formula=~GrazingTrt)), groups="GrazingTrt")
  
  # DSR varies by burning in current year (yes/no)
  Watershed=mark(GRSPnests,nocc=occ,model="Nest",
                 model.parameters=list(S=list(formula=~BurnedThisYear)), groups="BurnedThisYear")
  
  # DSR varies by burning and grazing
  GrazeBurn=mark(GRSPnests,nocc=occ,model="Nest",
               model.parameters=list(S=list(formula=~GrazingTrt+BurnedThisYear)), groups=c("GrazingTrt","BurnedThisYear"))
  
    # DSR varies by grazing and nest date
 GrazeDate=mark(GRSPnests,nocc=occ,model="Nest",
                  model.parameters=list(S=list(formula=~GrazingTrt+Time)), groups="GrazingTrt")
  
  # DSR varies by year and grazing 
  GrazeYear=mark(GRSPnests,nocc=occ,model="Nest",
                      model.parameters=list(S=list(formula=~Year+GrazingTrt)), groups=c("Year","GrazingTrt"))
  
    # DSR varies by burning and nest date
  BurnDate=mark(GRSPnests,nocc=occ,model="Nest",
                 model.parameters=list(S=list(formula=~BurnedThisYear+Time)), groups="BurnedThisYear")
 
   # DSR varies by burning and year
  BurnYear=mark(GRSPnests,nocc=occ,model="Nest",
                model.parameters=list(S=list(formula=~BurnedThisYear+Year)), groups=c("BurnedThisYear","Year"))
  
  # DSR varies by year and nest date
  YearDate=mark(GRSPnests,nocc=occ,model="Nest",
                model.parameters=list(S=list(formula=~Year+Time)), groups="Year")
  
  # DSR varies by grazing and quadratic nest date
  GrazeDateq=mark(GRSPnests,nocc=occ,model="Nest",
                   model.parameters=list(S=list(formula=~GrazingTrt+Time+I(Time^2))), groups="GrazingTrt")
  
  # DSR varies by burning and quadratic nest date
  BurnDateq=mark(GRSPnests,nocc=occ,model="Nest",
                  model.parameters=list(S=list(formula=~BurnedThisYear+Time+I(Time^2))), groups="BurnedThisYear")
  
  # DSR varies by year and quadratic nest date
  YearDateq=mark(GRSPnests,nocc=occ,model="Nest",
                 model.parameters=list(S=list(formula=~Year+Time+I(Time^2))), groups="Year")
  
  # DSR varies by grazing, burning, and nest date
  GrazeBurnDate=mark(GRSPnests,nocc=occ,model="Nest",
                 model.parameters=list(S=list(formula=~GrazingTrt+BurnedThisYear+Time)), groups=c("GrazingTrt", "BurnedThisYear"))
  
  # DSR varies by grazing, burning, and year
  GrazeBurnYear=mark(GRSPnests,nocc=occ,model="Nest",
                     model.parameters=list(S=list(formula=~GrazingTrt+BurnedThisYear+Year)), groups=c("GrazingTrt", "BurnedThisYear", "Year"))
  
  # DSR varies by grazing, year, and nest date
  GrazeYearDate=mark(GRSPnests,nocc=occ,model="Nest",
                     model.parameters=list(S=list(formula=~GrazingTrt+Year+Time)), groups=c("GrazingTrt", "Year"))
  
  # DSR varies by burning, year, and nest date
  BurnYearDate=mark(GRSPnests,nocc=occ,model="Nest",
                     model.parameters=list(S=list(formula=~BurnedThisYear+Year+Time)), groups=c("BurnedThisYear", "Year"))
  
  # DSR varies by grazing, burning, year, and nest date
  GrazeBurnYearDate=mark(GRSPnests,nocc=occ,model="Nest",
                    model.parameters=list(S=list(formula=~GrazingTrt+BurnedThisYear+Year+Time)), groups=c("GrazingTrt","BurnedThisYear", "Year"))
 
   # DSR varies by grazing, year, and quadratic nest date
  GrazeYearDateq=mark(GRSPnests,nocc=occ,model="Nest",
               model.parameters=list(S=list(formula=~GrazingTrt+Year+Time+I(Time^2))), groups=c("GrazingTrt","Year"))
  
  # DSR varies by grazing, burning, and quadratic nest date
  GrazeBurnDateq=mark(GRSPnests,nocc=occ,model="Nest",
                      model.parameters=list(S=list(formula=~GrazingTrt+BurnedThisYear+Time+I(Time^2))), groups=c("GrazingTrt","BurnedThisYear"))
  
  # DSR varies by grazing, burning, year, and quadratic nest date
  GrazeBurnYearDateq=mark(GRSPnests,nocc=occ,model="Nest",
                      model.parameters=list(S=list(formula=~GrazingTrt+BurnedThisYear+Year+Time+I(Time^2))), groups=c("GrazingTrt","BurnedThisYear", "Year"))
  
    # DSR varies by grazing, year, and interaction
  GrazeYearInt=mark(GRSPnests,nocc=occ,model="Nest",
                    model.parameters=list(S=list(formula=~GrazingTrt+Year+GrazingTrt*Year)), groups=c("GrazingTrt", "Year"))
 
   # DSR varies by burning, year, and interaction
  BurnYearInt=mark(GRSPnests,nocc=occ,model="Nest",
                    model.parameters=list(S=list(formula=~BurnedThisYear+Year+BurnedThisYear*Year)), groups=c("BurnedThisYear", "Year"))
 
   # DSR varies by nest date, year, and interaction
  YearDateInt=mark(GRSPnests,nocc=occ,model="Nest",
                    model.parameters=list(S=list(formula=~Year+Time+Year*Time)), groups="Year")
 
   # DSR varies by grazing, burning, and interaction
 GrazeBurnInt=mark(GRSPnests,nocc=occ,model="Nest",
                model.parameters=list(S=list(formula=~GrazingTrt+BurnedThisYear+GrazingTrt*BurnedThisYear)), groups=c("GrazingTrt", "BurnedThisYear"))
  
 # DSR varies by grazing, nest date, and interaction
 GrazeDateInt=mark(GRSPnests,nocc=occ,model="Nest",
                  model.parameters=list(S=list(formula=~GrazingTrt+Time+GrazingTrt*Time)), groups="GrazingTrt")
 
 # DSR varies by burning, nest date, and interaction
 BurnDateInt=mark(GRSPnests,nocc=occ,model="Nest",
                model.parameters=list(S=list(formula=~BurnedThisYear+Time+BurnedThisYear*Time)), groups="BurnedThisYear")
 
 # DSR varies by year and quad nest date, and interaction
 YearDateqInt=mark(GRSPnests,nocc=occ,model="Nest",
              model.parameters=list(S=list(formula=~Year+Time+I(Time^2)+Year*I(Time^2))), groups="Year")
 
 
   # Return model table and list of models
  return(collect.models())
}

GRSPnests.results=run.GRSPnests() # This runs the models above and takes a minute or 2
GRSPnests.results # print model selection table to screen
# Look for STOP NORMAL EXIT message after each model


#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine table of model selection results 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#

options(width=100) # set page width to 100 characters
sink("results.table.txt") # capture screen output to file
print.marklist(GRSPnests.results) # send output to file
sink() # return output to screen
system("notepad results.table.txt",invisible=FALSE)




